@@ -16,7 +16,7 @@ from .forms import *
 from .utils import get_outliers
 from .tasks import doBasicAnalysis,doReset
 
-def testAnalysis():
+def testAnalysis(form):
     goodWords = ['back', 'bad', 'badge', 'bag', 'ball', 'bar', 'bare', 'base', 'bash', 'bass', 'bat', 'bath', 'beach', 'bean', 'bear', 'beat',
                  'bed', 'beer', 'bell', 'berth', 'big', 'bike', 'bill', 'birth', 'bitch', 'bite', 'boat', 'bob', 'boil', 'bomb', 'book', 'boom', 'boon',
                  'boss', 'bought', 'bout', 'bowl', 'buck', 'bum', 'burn', 'bus', 'bush', 'cab', 'cad', 'cake', 'calf', 'call', 'came', 'cap',
@@ -95,7 +95,7 @@ def basic(request):
             form = AnalysisForm(request.POST)
             if form.is_valid():
                 if settings.DEBUG:
-                    testAnalysis()
+                    testAnalysis(form.cleaned_data)
                 else:
                     doBasicAnalysis.delay(form.cleaned_data)
                 return redirect(index)
